LruHashSet

Struct LruHashSet 

pub struct LruHashSet<K> { /* private fields */ }
A LRU HashSet implementation

Implementations

Source

impl<K> LruHashSet<K>
where K: Hash + Eq,

pub fn with_max_entries(max_entries: usize) -> Self

Creates a new LruHashSet with a given number of entries

pub fn get(&mut self, k: &K) -> Option<Rc<K>>

Returns a reference to the value in the set, if any, that is equal to the given value.

pub fn iter(&mut self) -> Iter<'_, K>

Returns an iterator over the values within the set

Warning

Iterating does not modify the order of the LRU to prevent any unwanted side effects due.

pub fn contains(&mut self, k: &K) -> bool

Returns true if there is an element is in the set

pub fn insert(&mut self, k: K) -> bool

Adds a value to the set.

Returns whether the value was newly inserted. That is:

  • If the set did not previously contain this value, true is returned.
  • If the set already contained this value, false is returned, and the set is not modified: original value is not replaced, and the value passed as argument is dropped.
pub fn remove(&mut self, k: &K) -> bool

Removes an entry from the LruHashSet and returns true if the entry was removed else false

pub fn len(&self) -> usize

Returns the length of the LruHashSet

pub fn cap(&self) -> usize

Returns the capacity of the LruHashSet

pub fn is_empty(&self) -> bool

Returns true if the LruHashSet is empty

pub fn is_full(&self) -> bool

Returns true if the LruHashSet is full